Ladda: Bootstrap compatibility test
Author: Hakim El Hattab

# Ladda

A UI concept which merges loading indicators into the action that invoked them. Primarily intended for use with forms where it gives users immediate feedback upon submit rather than leaving them wondering while the browser does its thing. For a real-world example, check out any of the forms on slid.es.

### expand-left

### expand-right

### expand-up

### expand-down

### zoom-in

### zoom-out

### slide-left

### slide-right

### slide-up

### slide-down

### Built-in progress bar

### expand-right

### contract

### Sizes

### Extra Small

### Small

### Large

### Buttons in forms containing required inputs